.. :changelog:

History
-------

0.0.1 (19-07-2019)
---------------------

* First code creation


0.1.0 (19-07-2019)
------------------

* initial code implementation


0.2.0 (20-07-2019)
------------------

* Exposed transaction objects


0.2.1 (20-07-2019)
------------------

* Reverted to default provided value for account transaction amount


0.3.0 (21-07-2019)
------------------

* Removed uneeded properties from account transaction


0.4.0 (21-07-2019)
------------------

* Exposed actually existing attribute


1.0.0 (24-07-2019)
------------------

* Initial working version with accounts, foreign accounts and transaction retrieval.


1.0.1 (25-07-2019)
------------------

* made credit card a Comparable
